==> haskell-hls-call-hierarchy-plugin-1.2.0.0-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-call-hierarchy-plugin
version:              1.2.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-1.2.0.0-9vp7mHQMDp28JeXe3Jay7r
key:                  hls-call-hierarchy-plugin-1.2.0.0-9vp7mHQMDp28JeXe3Jay7r
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  3e9cad41ea7999498272d175ece01b18
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-1.2.0.0-9vp7mHQMDp28JeXe3Jay7r
depends:
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-KspoS0yodOb8Msf7MgdZ07
    ghcide-1.10.0.0-8YNBVtwkfPOEXcK9jmX81b
    hiedb-0.4.3.0-Gw4hdUpybo64gMvVx0zfDM
    hls-plugin-api-1.6.0.0-9wGoIV0w1AI6MQx1RgDVdm
    lens-5.2.3-LJCKq2CVV0OBzhsqfjAjcB
    lsp-1.6.0.0-AdGydXppFhq7XJ93v8D4rR
    sqlite-simple-0.4.19.0-FxCBkxfetHWG7136TzJtwf text-1.2.5.0
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-call-hierarchy-plugin-1.2.0.0-211-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-call-hierarchy-plugin
version:              1.2.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-1.2.0.0-B8QVIEvrtX2L9pZooCqPw8
key:                  hls-call-hierarchy-plugin-1.2.0.0-B8QVIEvrtX2L9pZooCqPw8
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  68cf2df57f925df4bf39fa99abda28ae
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-1.2.0.0-B8QVIEvrtX2L9pZooCqPw8
depends:
    aeson-2.1.2.1-5xA96pEAe1OF80YjsNpBtK base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-2mdugPLlpsLFCymFYwYPi2
    ghcide-1.10.0.0-HHQ8G8WsjSJ2AEMQGOwX6
    hiedb-0.4.3.0-5HrQNNomUCP2wQ9ACGDUtt
    hls-plugin-api-1.6.0.0-J7scbURco0w3rSkQkePbC4
    lens-5.2.3-Ip76jddesOj5vmVbK7jYXC
    lsp-1.6.0.0-2t8x0RCtMfUJVfdZdVq4q7
    sqlite-simple-0.4.19.0-FxCBkxfetHWG7136TzJtwf text-1.2.5.0
    unordered-containers-0.2.20-9qtKP8IRTHnKAJSp2mdpwo

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
